@@ -5,7 +5,7 @@
 
 		<?php if (isset($this->data['error'])) { ?>
 		<div style="border-left: 1px solid #e8e8e8; border-bottom: 1px solid #e8e8e8; background: #f5f5f5">
-		<img src="/<?php echo $this->data['baseurlpath']; ?>resources/icons/experience/gtk-dialog-error.48x48.png" class="float-l erroricon" style="margin: 15px " />
+		<img src="/<?php echo $this->data['baseurlpath']; ?>resources/icons/experience/gtk-dialog-error.48x48.png" class="float-l erroricon" style="margin: 15px" alt="" />
 		<h2><?php echo $this->t('error_header'); ?></h2>
 		
 		<p class="logintext"><?php echo htmlspecialchars($this->data['error']); ?> </p>
@@ -22,7 +22,7 @@
 
 		<table>
 			<tr>
-				<td rowspan="3"><img src="/<?php echo $this->data['baseurlpath']; ?>resources/icons/experience/gtk-dialog-authentication.48x48.png" id="loginicon" /></td>
+				<td rowspan="3"><img src="/<?php echo $this->data['baseurlpath']; ?>resources/icons/experience/gtk-dialog-authentication.48x48.png" id="loginicon" alt="" /></td>
 				<td style="padding: .3em;"><?php echo $this->t('username'); ?></td>
 				<td><input type="text" tabindex="1" name="username" 
 					<?php if (isset($this->data['username'])) {
@@ -31,7 +31,7 @@
 
 					
 				<td style="padding: .4em;" rowspan="3">
-					<input type="submit" tabindex="3" id="regularsubmit" value="<?php echo $this->t('login_button'); ?>" />
+					<button type="submit" tabindex="3" id="regularsubmit" class="btn"><?php echo $this->t('login_button'); ?></button>
 					<input type="hidden" name="RelayState" value="<?php echo htmlspecialchars($this->data['relaystate']); ?>" />
 				</td>
 			</tr>
@@ -56,7 +56,7 @@
 				<td><input type="password" tabindex="2" name="password" /></td>
 			</tr>
 		<tr><td></td><td>
-		<input type="submit" tabindex="5" id="mobilesubmit" value="<?php echo $this->t('login_button'); ?>" />
+		<button type="submit" tabindex="5" id="mobilesubmit" class="btn"><?php echo $this->t('login_button'); ?></button>
 		</td></tr>
 		</table>
 		
